==> haskell-tasty-hunit-0.10.1-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hunit
version:              0.10.1
visibility:           public
id:                   tasty-hunit-0.10.1-9NQUK4KvFB5GqbivTe1SAy
key:                  tasty-hunit-0.10.1-9NQUK4KvFB5GqbivTe1SAy
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.

    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.

category:             Testing
abi:                  ed993578a224a054027f9798722ef71e
exposed:              True
exposed-modules:      Test.Tasty.HUnit
hidden-modules:       Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-hunit-0.10.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-hunit-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hunit
hs-libraries:         HStasty-hunit-0.10.1-9NQUK4KvFB5GqbivTe1SAy
depends:
    base-4.16.4.0 call-stack-0.4.0-7Kj6UtaYY94JDoMxAZHX8y
    tasty-1.4.3-IJrCoaUld1J8JxqIiOPgQd

haddock-interfaces:   /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hunit-0.10.1-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hunit
version:              0.10.1
visibility:           public
id:                   tasty-hunit-0.10.1-6xGD3lXeoy09BhrZcQbIIT
key:                  tasty-hunit-0.10.1-6xGD3lXeoy09BhrZcQbIIT
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.

    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.

category:             Testing
abi:                  0a46f943f35dbecdce964d49cee3ec7c
exposed:              True
exposed-modules:      Test.Tasty.HUnit
hidden-modules:       Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-hunit-0.10.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-hunit-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hunit
hs-libraries:         HStasty-hunit-0.10.1-6xGD3lXeoy09BhrZcQbIIT
depends:
    base-4.16.4.0 call-stack-0.4.0-IMwEyMKUWi374Iju6AMdwQ
    tasty-1.4.3-Cv2gN4EvQr169nfvQOHPzP

haddock-interfaces:   /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
